@@ -21,7 +21,7 @@ import 'package:analyzer/src/dart/resolver/ast_rewrite.dart';
 import 'package:analyzer/src/dart/resolver/named_type_resolver.dart';
 import 'package:analyzer/src/dart/resolver/scope.dart';
 import 'package:analyzer/src/error/codes.dart';
-import 'package:analyzer/src/generated/declaration_resolver.dart';
+import 'package:analyzer/src/generated/element_walker.dart';
 import 'package:analyzer/src/generated/utilities_dart.dart';
 
 class ElementHolder {
@@ -140,7 +140,10 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   DartType get _dynamicType => _typeProvider.dynamicType;
 
   @override
-  void visitAnnotation(Annotation node) {
+  void visitAnnotation(covariant AnnotationImpl node) {
+    if (_elementWalker == null) {
+      _createElementAnnotation(node);
+    }
     _withElementWalker(null, () {
       super.visitAnnotation(node);
     });
@@ -220,8 +223,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     node.name.staticElement = element;
     _namedTypeResolver.enclosingClass = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementWalker(ElementWalker.forClass(element), () {
       _withNameScope(() {
@@ -235,7 +237,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
           ErrorCode errorCode = withClause == null
               ? CompileTimeErrorCode.EXTENDS_NON_CLASS
               : CompileTimeErrorCode.MIXIN_WITH_NON_CLASS_SUPERCLASS;
-          _resolveType(extendsClause.superclass2, errorCode, asClass: true);
+          _resolveType(extendsClause.superclass, errorCode, asClass: true);
         }
 
         _resolveWithClause(withClause);
@@ -256,8 +258,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     node.name.staticElement = element;
     _namedTypeResolver.enclosingClass = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementWalker(ElementWalker.forClass(element), () {
       _withNameScope(() {
@@ -265,7 +266,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
         node.typeParameters?.accept(this);
 
         _resolveType(
-          node.superclass2,
+          node.superclass,
           CompileTimeErrorCode.MIXIN_WITH_NON_CLASS_SUPERCLASS,
           asClass: true,
         );
@@ -284,8 +285,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     (node as ConstructorDeclarationImpl).declaredElement = element;
     node.name?.staticElement = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementHolder(ElementHolder(element), () {
       _withElementWalker(null, () {
@@ -392,38 +392,53 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     var element = _elementWalker!.getVariable();
     node.name.staticElement = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
+
+    var arguments = node.arguments;
+    if (arguments != null) {
+      _withElementWalker(null, () {
+        _withElementHolder(ElementHolder(element), () {
+          arguments.accept(this);
+        });
+      });
+    }
   }
 
   @override
   void visitEnumDeclaration(covariant EnumDeclarationImpl node) {
     EnumElementImpl element = _elementWalker!.getEnum();
     node.name.staticElement = element;
+    _namedTypeResolver.enclosingClass = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementWalker(ElementWalker.forClass(element), () {
       _withNameScope(() {
         _buildTypeParameterElements(node.typeParameters);
         node.typeParameters?.accept(this);
 
+        _resolveWithClause(node.withClause);
+        _resolveImplementsClause(node.implementsClause);
+
         _defineElements(element.accessors);
         _defineElements(element.methods);
         node.constants.accept(this);
         node.members.accept(this);
       });
     });
+
+    _namedTypeResolver.enclosingClass = null;
   }
 
   @override
   void visitExportDirective(ExportDirective node) {
+    var element = node.element;
+    if (element is ExportElementImpl) {
+      _setOrCreateMetadataElements(element, node.metadata);
+    }
+
     _withElementWalker(null, () {
       super.visitExportDirective(node);
-      if (node.element != null) {
-        _setElementAnnotations(node.metadata, node.element!.metadata);
-      }
     });
   }
 
@@ -433,8 +448,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     (node as ExtensionDeclarationImpl).declaredElement = element;
     node.name?.staticElement = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementWalker(ElementWalker.forExtension(element), () {
       _withNameScope(() {
@@ -449,14 +463,6 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     });
   }
 
-  @override
-  void visitFieldDeclaration(FieldDeclaration node) {
-    super.visitFieldDeclaration(node);
-    var firstFieldElement =
-        node.fields.variables[0].declaredElement as FieldElement;
-    _setElementAnnotations(node.metadata, firstFieldElement.metadata);
-  }
-
   @override
   void visitFieldFormalParameter(covariant FieldFormalParameterImpl node) {
     FieldFormalParameterElementImpl element;
@@ -624,8 +630,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     var element = _elementWalker!.getTypedef();
     node.name.staticElement = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementWalker(ElementWalker.forTypedef(element), () {
       _withNameScope(() {
@@ -739,8 +744,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     var element = _elementWalker!.getTypedef();
     node.name.staticElement = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementWalker(ElementWalker.forGenericTypeAlias(element), () {
       _withNameScope(() {
@@ -753,11 +757,13 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
   @override
   void visitImportDirective(ImportDirective node) {
+    var element = node.element;
+    if (element is ImportElementImpl) {
+      _setOrCreateMetadataElements(element, node.metadata);
+    }
+
     _withElementWalker(null, () {
       super.visitImportDirective(node);
-      if (node.element != null) {
-        _setElementAnnotations(node.metadata, node.element!.metadata);
-      }
     });
   }
 
@@ -765,7 +771,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   void visitInstanceCreationExpression(InstanceCreationExpression node) {
     var newNode = _astRewriter.instanceCreationExpression(_nameScope, node);
     if (newNode != node) {
-      if (node.constructorName.type2.typeArguments != null &&
+      if (node.constructorName.type.typeArguments != null &&
           newNode is MethodInvocation &&
           newNode.target is FunctionReference &&
           !_libraryElement.featureSet.isEnabled(Feature.constructor_tearoffs)) {
@@ -810,18 +816,15 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
   @override
   void visitLibraryDirective(LibraryDirective node) {
-    super.visitLibraryDirective(node);
     ++_libraryDirectiveIndex;
-    if (node.element != null && _libraryDirectiveIndex == 1) {
-      _setElementAnnotations(node.metadata, node.element!.metadata);
-    } else {
-      for (var annotation in node.metadata) {
-        annotation as AnnotationImpl;
-        var elementAnnotation = ElementAnnotationImpl(_unitElement);
-        elementAnnotation.annotationAst = annotation;
-        annotation.elementAnnotation = elementAnnotation;
-      }
+    var element = node.element;
+    if (element is LibraryElementImpl && _libraryDirectiveIndex == 1) {
+      _setOrCreateMetadataElements(element, node.metadata);
     }
+
+    _withElementWalker(null, () {
+      super.visitLibraryDirective(node);
+    });
   }
 
   @override
@@ -831,8 +834,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
         : _elementWalker!.getFunction();
     node.name.staticElement = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementWalker(ElementWalker.forExecutable(element), () {
       node.metadata.accept(this);
@@ -867,8 +869,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     var element = _elementWalker!.getMixin();
     node.name.staticElement = element;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     _withElementWalker(ElementWalker.forClass(element), () {
       _withNameScope(() {
@@ -899,18 +900,21 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
   @override
   void visitPartDirective(PartDirective node) {
+    var element = node.element;
+    if (element is CompilationUnitElementImpl) {
+      _setOrCreateMetadataElements(element, node.metadata);
+    }
+
     _withElementWalker(null, () {
       super.visitPartDirective(node);
-      if (node.element != null) {
-        _setElementAnnotations(node.metadata, node.element!.metadata);
-      }
     });
   }
 
   @override
   void visitPartOfDirective(PartOfDirective node) {
-    _createElementAnnotations(node.metadata);
-    super.visitPartOfDirective(node);
+    _withElementWalker(null, () {
+      super.visitPartOfDirective(node);
+    });
   }
 
   @override
@@ -1058,8 +1062,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   void visitTypeParameter(TypeParameter node) {
     var element = node.declaredElement as TypeParameterElementImpl;
 
-    node.metadata.accept(this);
-    _setElementAnnotations(node.metadata, element.metadata);
+    _setOrCreateMetadataElements(element, node.metadata);
 
     var boundNode = node.bound;
     if (boundNode != null) {
@@ -1122,7 +1125,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     for (var i = 0; i < variables.length; i++) {
       var variable = variables[i];
       var element = variable.declaredElement as ElementImpl;
-      _setOrCreateMetadataElements(element, annotations);
+      _setOrCreateMetadataElements(element, annotations, visitNodes: false);
 
       var offset = (i == 0 ? node.parent! : variable).offset;
       var length = variable.end - offset;
@@ -1223,20 +1226,11 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     }
   }
 
-  /// For each [Annotation] found in [annotations], create a new
-  /// [ElementAnnotation] object and set the [Annotation] to point to it.
-  List<ElementAnnotation> _createElementAnnotations(
-      List<Annotation> annotations) {
-    if (annotations.isEmpty) {
-      return const <ElementAnnotation>[];
-    }
-    return annotations.map((annotation) {
-      annotation as AnnotationImpl;
-      var elementAnnotation = ElementAnnotationImpl(_unitElement);
-      elementAnnotation.annotationAst = annotation;
-      annotation.elementAnnotation = elementAnnotation;
-      return elementAnnotation;
-    }).toList();
+  /// Create a new [ElementAnnotation] for the [node].
+  void _createElementAnnotation(AnnotationImpl node) {
+    var element = ElementAnnotationImpl(_unitElement);
+    element.annotationAst = node;
+    node.elementAnnotation = element;
   }
 
   void _define(Element element) {
@@ -1278,7 +1272,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     if (clause == null) return;
 
     _resolveTypes(
-      clause.interfaces2,
+      clause.interfaces,
       CompileTimeErrorCode.IMPLEMENTS_NON_CLASS,
     );
   }
@@ -1287,7 +1281,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     if (clause == null) return;
 
     _resolveTypes(
-      clause.superclassConstraints2,
+      clause.superclassConstraints,
       CompileTimeErrorCode.MIXIN_SUPER_CLASS_CONSTRAINT_NON_INTERFACE,
     );
   }
@@ -1296,7 +1290,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
     var redirectedConstructor = node.redirectedConstructor;
     if (redirectedConstructor == null) return;
 
-    var namedType = redirectedConstructor.type2;
+    var namedType = redirectedConstructor.type;
     _namedTypeResolver.redirectedConstructor_namedType = namedType;
 
     redirectedConstructor.accept(this);
@@ -1357,7 +1351,7 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
   void _resolveWithClause(WithClause? clause) {
     if (clause == null) return;
 
-    for (var namedType in clause.mixinTypes2) {
+    for (var namedType in clause.mixinTypes) {
       _namedTypeResolver.withClause_namedType = namedType;
       _resolveType(
         namedType as NamedTypeImpl,
@@ -1373,13 +1367,18 @@ class ResolutionVisitor extends RecursiveAstVisitor<void> {
 
   void _setOrCreateMetadataElements(
     ElementImpl element,
-    NodeList<Annotation> annotations,
-  ) {
-    annotations.accept(this);
+    NodeList<Annotation> annotations, {
+    bool visitNodes = true,
+  }) {
+    if (visitNodes) {
+      annotations.accept(this);
+    }
     if (_elementWalker != null) {
       _setElementAnnotations(annotations, element.metadata);
-    } else {
-      element.metadata = _createElementAnnotations(annotations);
+    } else if (annotations.isNotEmpty) {
+      element.metadata = annotations.map((annotation) {
+        return annotation.elementAnnotation!;
+      }).toList();
     }
   }
 
