@@ -22,8 +22,10 @@ import 'package:analyzer/src/summary2/ast_binary_reader.dart';
 import 'package:analyzer/src/summary2/ast_binary_tag.dart';
 import 'package:analyzer/src/summary2/data_reader.dart';
 import 'package:analyzer/src/summary2/element_flags.dart';
+import 'package:analyzer/src/summary2/export.dart';
 import 'package:analyzer/src/summary2/informative_data.dart';
 import 'package:analyzer/src/summary2/linked_element_factory.dart';
+import 'package:analyzer/src/summary2/macro_application_error.dart';
 import 'package:analyzer/src/summary2/reference.dart';
 import 'package:analyzer/src/task/inference_error.dart';
 import 'package:pub_semver/pub_semver.dart';
@@ -32,7 +34,7 @@ class BundleReader {
   final SummaryDataReader _reader;
   final Map<Uri, Uint8List> _unitsInformativeBytes;
 
-  final Map<String, LibraryReader> libraryMap = {};
+  final Map<Uri, LibraryReader> libraryMap = {};
 
   BundleReader({
     required LinkedElementFactory elementFactory,
@@ -56,16 +58,16 @@ class BundleReader {
     _reader.offset = librariesOffset;
     var libraryHeaderList = _reader.readTypedList(() {
       return _LibraryHeader(
-        uriStr: _reader.readStringReference(),
+        uri: Uri.parse(_reader.readStringReference()),
         offset: _reader.readUInt30(),
         classMembersLengths: _reader.readUInt30List(),
       );
     });
 
     for (var libraryHeader in libraryHeaderList) {
-      var uriStr = libraryHeader.uriStr;
-      var reference = elementFactory.rootReference.getChild(uriStr);
-      libraryMap[uriStr] = LibraryReader._(
+      var uri = libraryHeader.uri;
+      var reference = elementFactory.rootReference.getChild('$uri');
+      libraryMap[uri] = LibraryReader._(
         elementFactory: elementFactory,
         reader: _reader,
         unitsInformativeBytes: _unitsInformativeBytes,
@@ -186,7 +188,7 @@ abstract class ElementLinkedData<E extends ElementImpl> {
 
   void read(ElementImpl element) {
     if (_offset == -1) {
-      return null;
+      return;
     }
 
     var dataReader = _libraryReader._reader.fork(_offset);
@@ -276,6 +278,9 @@ class EnumElementLinkedData extends ElementLinkedData<EnumElementImpl> {
       unitElement: element.enclosingElement,
     );
     _readTypeParameters(reader, element.typeParameters);
+    element.supertype = reader._readOptionalInterfaceType();
+    element.mixins = reader._readInterfaceTypeList();
+    element.interfaces = reader._readInterfaceTypeList();
     applyConstantOffsets?.perform();
   }
 }
@@ -406,8 +411,6 @@ class LibraryReader {
   final Uint32List _classMembersLengths;
   int _classMembersLengthsIndex = 0;
 
-  late List<Reference> exports;
-
   LibraryReader._({
     required LinkedElementFactory elementFactory,
     required SummaryDataReader reader,
@@ -460,10 +463,9 @@ class LibraryReader {
       units.add(unitElement);
     }
 
-    var exportsIndexList = _reader.readUInt30List();
-    exports = exportsIndexList
-        .map((index) => _referenceReader.referenceOfIndex(index))
-        .toList();
+    libraryElement.exportedReferences = _reader.readTypedList(
+      _readExportedReference,
+    );
 
     libraryElement.definingCompilationUnit = units[0];
     libraryElement.parts = units.skip(1).toList();
@@ -509,6 +511,9 @@ class LibraryReader {
     );
     element.setLinkedData(reference, linkedData);
     ClassElementFlags.read(_reader, element);
+    element.macroApplicationErrors = _reader.readTypedList(
+      () => MacroApplicationError(_reader),
+    );
 
     element.typeParameters = _readTypeParameters();
 
@@ -622,6 +627,26 @@ class LibraryReader {
     });
   }
 
+  ExportedReference _readExportedReference() {
+    final kind = _reader.readByte();
+    if (kind == 0) {
+      final index = _reader.readUInt30();
+      final reference = _referenceReader.referenceOfIndex(index);
+      return ExportedReferenceDeclared(
+        reference: reference,
+      );
+    } else if (kind == 1) {
+      final index = _reader.readUInt30();
+      final reference = _referenceReader.referenceOfIndex(index);
+      return ExportedReferenceExported(
+        reference: reference,
+        indexes: _reader.readUInt30List(),
+      );
+    } else {
+      throw StateError('kind: $kind');
+    }
+  }
+
   ExportElementImpl _readExportElement() {
     var element = ExportElementImpl(-1);
     element.uri = _reader.readOptionalStringReference();
@@ -1177,9 +1202,11 @@ class LibraryReader {
     var unitUri = Uri.parse(unitUriStr);
     var unitSource = sourceFactory.forUri2(unitUri)!;
 
-    var unitElement = CompilationUnitElementImpl();
-    unitElement.source = unitSource;
-    unitElement.librarySource = librarySource;
+    var unitElement = CompilationUnitElementImpl(
+      source: unitSource,
+      librarySource: librarySource,
+      lineInfo: LineInfo([0]),
+    );
 
     var unitReference = unitContainerRef.getChild(unitUriStr);
     unitElement.setLinkedData(
@@ -1793,7 +1820,7 @@ class TypeAliasElementLinkedData
 /// so that when we need to read this library, we know where it starts without
 /// reading previous libraries.
 class _LibraryHeader {
-  final String uriStr;
+  final Uri uri;
   final int offset;
 
   /// We don't read class members when reading libraries, by performance
@@ -1802,7 +1829,7 @@ class _LibraryHeader {
   final Uint32List classMembersLengths;
 
   _LibraryHeader({
-    required this.uriStr,
+    required this.uri,
     required this.offset,
     required this.classMembersLengths,
   });
