@@ -18,6 +18,8 @@ import 'package:analyzer/src/summary2/ast_binary_tag.dart';
 import 'package:analyzer/src/summary2/ast_binary_writer.dart';
 import 'package:analyzer/src/summary2/data_writer.dart';
 import 'package:analyzer/src/summary2/element_flags.dart';
+import 'package:analyzer/src/summary2/export.dart';
+import 'package:analyzer/src/summary2/macro_application_error.dart';
 import 'package:analyzer/src/summary2/reference.dart';
 import 'package:analyzer/src/task/inference_error.dart';
 import 'package:collection/collection.dart';
@@ -91,10 +93,7 @@ class BundleWriter {
     );
   }
 
-  void writeLibraryElement(
-    LibraryElementImpl libraryElement,
-    List<Reference> exports,
-  ) {
+  void writeLibraryElement(LibraryElementImpl libraryElement) {
     var libraryOffset = _sink.offset;
     _classMembersLengths = <int>[];
 
@@ -111,7 +110,7 @@ class BundleWriter {
     for (var unitElement in libraryElement.units) {
       _writeUnitElement(unitElement);
     }
-    _writeReferences(exports);
+    _writeExportedReferences(libraryElement.exportedReferences);
 
     _libraries.add(
       _Library(
@@ -129,6 +128,11 @@ class BundleWriter {
     _sink._writeStringReference(element.name);
     ClassElementFlags.write(_sink, element);
 
+    _sink.writeList<MacroApplicationError>(
+      element.macroApplicationErrors,
+      (x) => x.write(_sink),
+    );
+
     _resolutionSink._writeAnnotationList(element.metadata);
 
     _writeTypeParameters(element.typeParameters, () {
@@ -176,9 +180,14 @@ class BundleWriter {
     _resolutionSink._writeAnnotationList(element.metadata);
 
     _writeTypeParameters(element.typeParameters, () {
+      _resolutionSink.writeType(element.supertype);
+      _resolutionSink._writeTypeList(element.mixins);
+      _resolutionSink._writeTypeList(element.interfaces);
+
       _writeList(
         element.fields.where((e) {
-          return !e.isSynthetic || const {'index', 'values'}.contains(e.name);
+          return !e.isSynthetic ||
+              e is FieldElementImpl && e.isSyntheticEnumField;
         }).toList(),
         _writeFieldElement,
       );
@@ -191,6 +200,22 @@ class BundleWriter {
     });
   }
 
+  void _writeExportedReferences(List<ExportedReference> elements) {
+    _writeList<ExportedReference>(elements, (exported) {
+      final index = _references._indexOfReference(exported.reference);
+      if (exported is ExportedReferenceDeclared) {
+        _sink.writeByte(0);
+        _sink.writeUInt30(index);
+      } else if (exported is ExportedReferenceExported) {
+        _sink.writeByte(1);
+        _sink.writeUInt30(index);
+        _sink.writeUint30List(exported.indexes);
+      } else {
+        throw UnimplementedError('(${exported.runtimeType}) $exported');
+      }
+    });
+  }
+
   void _writeExportElement(ExportElement element) {
     _sink._writeOptionalStringReference(element.uri);
     _sink.writeList(element.combinators, _writeNamespaceCombinator);
@@ -377,16 +402,6 @@ class BundleWriter {
     _writeList(element.parameters, _writeParameterElement);
   }
 
-  void _writeReferences(List<Reference> references) {
-    var length = references.length;
-    _sink.writeUInt30(length);
-
-    for (var reference in references) {
-      var index = _references._indexOfReference(reference);
-      _sink.writeUInt30(index);
-    }
-  }
-
   void _writeTopLevelVariableElement(TopLevelVariableElement element) {
     element as TopLevelVariableElementImpl;
     _sink.writeUInt30(_resolutionSink.offset);
@@ -497,14 +512,10 @@ class ResolutionSink extends _SummaryDataWriter {
   final _LocalElementIndexer localElements = _LocalElementIndexer();
 
   ResolutionSink({
-    required ByteSink sink,
-    required StringIndexer stringIndexer,
+    required super.sink,
+    required super.stringIndexer,
     required _BundleWriterReferences references,
-  })  : _references = references,
-        super(
-          sink: sink,
-          stringIndexer: stringIndexer,
-        );
+  }) : _references = references;
 
   /// TODO(scheglov) Triage places where we write elements.
   /// Some of then cannot be members, e.g. type names.
