@@ -99,7 +99,7 @@ final String frontEndPkgPath =
 /// strings.  TODO(paulberry): share this regexp (and the code for interpreting
 /// it) between the CFE and analyzer.
 final RegExp _placeholderPattern =
-    RegExp("#\([-a-zA-Z0-9_]+\)(?:%\([0-9]*\)\.\([0-9]+\))?");
+    RegExp("#([-a-zA-Z0-9_]+)(?:%([0-9]*).([0-9]+))?");
 
 /// Convert a CFE template string (which uses placeholders like `#string`) to
 /// an analyzer template string (which uses placeholders like `{0}`).
@@ -236,24 +236,15 @@ List<String> _splitText(
 /// analyzer's `messages.yaml` file.
 class AnalyzerErrorCodeInfo extends ErrorCodeInfo {
   AnalyzerErrorCodeInfo(
-      {String? comment,
-      String? correctionMessage,
-      String? documentation,
-      bool hasPublishedDocs = false,
-      bool isUnresolvedIdentifier = false,
-      required String problemMessage,
-      String? sharedName})
-      : super(
-            comment: comment,
-            correctionMessage: correctionMessage,
-            documentation: documentation,
-            hasPublishedDocs: hasPublishedDocs,
-            isUnresolvedIdentifier: isUnresolvedIdentifier,
-            problemMessage: problemMessage,
-            sharedName: sharedName);
+      {super.comment,
+      super.correctionMessage,
+      super.documentation,
+      super.hasPublishedDocs,
+      super.isUnresolvedIdentifier,
+      required super.problemMessage,
+      super.sharedName});
 
-  AnalyzerErrorCodeInfo.fromYaml(Map<Object?, Object?> yaml)
-      : super.fromYaml(yaml);
+  AnalyzerErrorCodeInfo.fromYaml(super.yaml) : super.fromYaml();
 }
 
 /// Data tables mapping between CFE errors and their corresponding automatically
@@ -474,18 +465,15 @@ abstract class ErrorCodeInfo {
     var maxWidth = 80 - 8 /* indentation */ - 2 /* quotes */ - 1 /* comma */;
     final placeholderToIndexMap = computePlaceholderToIndexMap();
     var messageAsCode = convertTemplate(placeholderToIndexMap, problemMessage);
-    out.writeln(_splitText(messageAsCode,
-                maxWidth: maxWidth, firstLineWidth: maxWidth + 4)
-            .map(json.encode)
-            .join('\n') +
-        ',');
+    var messageLines = _splitText(messageAsCode,
+        maxWidth: maxWidth, firstLineWidth: maxWidth + 4);
+    out.writeln('${messageLines.map(json.encode).join('\n')},');
     final correctionMessage = this.correctionMessage;
     if (correctionMessage is String) {
       out.write('correctionMessage: ');
       var code = convertTemplate(placeholderToIndexMap, correctionMessage);
-      out.writeln(
-          _splitText(code, maxWidth: maxWidth).map(json.encode).join('\n') +
-              ',');
+      var codeLines = _splitText(code, maxWidth: maxWidth);
+      out.writeln('${codeLines.map(json.encode).join('\n')},');
     }
     if (hasPublishedDocs) {
       out.writeln('hasPublishedDocs:true,');
@@ -505,16 +493,8 @@ abstract class ErrorCodeInfo {
     var out = StringBuffer();
     var comment = this.comment;
     if (comment != null) {
-      out.writeln('$indent/**');
       for (var line in comment.split('\n')) {
-        out.writeln('$indent *${line.isEmpty ? '' : ' '}$line');
-      }
-      out.writeln('$indent */');
-    }
-    var documentation = this.documentation;
-    if (documentation != null) {
-      for (var line in documentation.split('\n')) {
-        out.writeln('$indent//${line.isEmpty ? '' : ' '}$line');
+        out.writeln('$indent/// ${line.isEmpty ? '' : ' '}$line');
       }
     }
     return out.toString();
@@ -542,10 +522,10 @@ class FrontEndErrorCodeInfo extends ErrorCodeInfo {
   /// The index of the error in the analyzer's `fastaAnalyzerErrorCodes` table.
   final int? index;
 
-  FrontEndErrorCodeInfo.fromYaml(Map<Object?, Object?> yaml)
+  FrontEndErrorCodeInfo.fromYaml(super.yaml)
       : analyzerCode = _decodeAnalyzerCode(yaml['analyzerCode']),
         index = yaml['index'] as int?,
-        super.fromYaml(yaml);
+        super.fromYaml();
 
   @override
   Map<Object?, Object?> toYaml() => {
