@@ -217,7 +217,7 @@ class DartCommonLaunchAttachRequestArguments extends RequestArguments {
       : restart = obj['restart'],
         name = obj['name'] as String?,
         cwd = obj['cwd'] as String?,
-        env = obj['env'] as Map<String, String>?,
+        env = (obj['env'] as Map<String, Object?>?)?.cast<String, String>(),
         additionalProjectPaths =
             (obj['additionalProjectPaths'] as List?)?.cast<String>(),
         debugSdkLibraries = obj['debugSdkLibraries'] as bool?,
@@ -419,7 +419,8 @@ abstract class DartDebugAdapter<TL extends LaunchRequestArguments,
     this.enableDds = true,
     this.enableAuthCodes = true,
     this.logger,
-  }) : super(channel) {
+    Function? onError,
+  }) : super(channel, onError: onError) {
     channel.closed.then((_) => shutdown());
 
     _isolateManager = IsolateManager(this);
@@ -482,6 +483,10 @@ abstract class DartDebugAdapter<TL extends LaunchRequestArguments,
     isAttach = true;
     _subscribeToOutputStreams = true;
 
+    // When attaching to a process, suppress auto-resuming isolates until the
+    // first time the user resumes anything.
+    _isolateManager.autoResumeStartingIsolates = false;
+
     // Common setup.
     await _prepareForLaunchOrAttach(null);
 
@@ -538,13 +543,11 @@ abstract class DartDebugAdapter<TL extends LaunchRequestArguments,
   /// The URI protocol will be changed to ws/wss but otherwise not normalised.
   /// The caller should handle any other normalisation (such as adding /ws to
   /// the end if required).
-  ///
-  /// If [resumeIfStarting] is true, isolates waiting to start will
-  /// automatically be resumed. This is usually desired in launch requests, but
-  /// not when attaching.
   Future<void> connectDebugger(
     Uri uri, {
-    required bool resumeIfStarting,
+    // TODO(dantup): Remove this after parameter after updating the Flutter
+    //   DAP to not pass it.
+    bool? resumeIfStarting,
   }) async {
     // Start up a DDS instance for this VM.
     if (enableDds) {
@@ -577,15 +580,8 @@ abstract class DartDebugAdapter<TL extends LaunchRequestArguments,
     final vmService = await _vmServiceConnectUri(uri.toString());
     logger?.call('Connected to debugger at $uri!');
 
-    // Send a custom event with the VM Service URI as the editor might want to
-    // know about this (for example so it can connect an embedded DevTools to
-    // this app).
-    sendEvent(
-      RawEventBody({
-        'vmServiceUri': uri.toString(),
-      }),
-      eventType: 'dart.debuggerUris',
-    );
+    // Send debugger URI to the client.
+    sendDebuggerUris(uri);
 
     this.vmService = vmService;
 
@@ -622,18 +618,29 @@ abstract class DartDebugAdapter<TL extends LaunchRequestArguments,
     await debuggerConnected(vmInfo);
 
     await _withErrorHandling(
-      () => _configureExistingIsolates(vmService, vmInfo, resumeIfStarting),
+      () => _configureExistingIsolates(vmService, vmInfo),
     );
 
     _debuggerInitializedCompleter.complete();
   }
 
+  void sendDebuggerUris(Uri uri) {
+    // Send a custom event with the VM Service URI as the editor might want to
+    // know about this (for example so it can connect an embedded DevTools to
+    // this app).
+    sendEvent(
+      RawEventBody({
+        'vmServiceUri': uri.toString(),
+      }),
+      eventType: 'dart.debuggerUris',
+    );
+  }
+
   /// Process any existing isolates that may have been created before the
   /// streams above were set up.
   Future<void> _configureExistingIsolates(
     vm.VmService vmService,
     vm.VM vmInfo,
-    bool resumeIfStarting,
   ) async {
     final existingIsolateRefs = vmInfo.isolates;
     final existingIsolates = existingIsolateRefs != null
@@ -659,12 +666,11 @@ abstract class DartDebugAdapter<TL extends LaunchRequestArguments,
       if (isolate.pauseEvent?.kind?.startsWith('Pause') ?? false) {
         await _isolateManager.handleEvent(
           isolate.pauseEvent!,
-          resumeIfStarting: resumeIfStarting,
         );
       } else if (isolate.runnable == true) {
         // If requested, automatically resume. Otherwise send a Stopped event to
         // inform the client UI the thread is paused.
-        if (resumeIfStarting) {
+        if (_isolateManager.autoResumeStartingIsolates) {
           await _isolateManager.resumeIsolate(isolate);
         } else {
           _isolateManager.sendStoppedOnEntryEvent(thread.threadId);
@@ -1622,7 +1628,7 @@ abstract class DartDebugAdapter<TL extends LaunchRequestArguments,
 
   /// Creates one or more OutputEvents for the provided [message].
   ///
-  /// Messages that contain stack traces may be split up into seperate events
+  /// Messages that contain stack traces may be split up into separate events
   /// for each frame to allow location metadata to be attached.
   Future<List<OutputEventBody>> _buildOutputEvents(
     String category,
