@@ -1,7 +1,8 @@
 import 'package:test/test.dart';
 import 'package:xml/xml.dart';
 
-import 'assertions.dart';
+import 'utils/assertions.dart';
+import 'utils/matchers.dart';
 
 void main() {
   test('basic', () {
@@ -37,7 +38,7 @@ void main() {
   test('all', () {
     final builder = XmlBuilder();
     builder.declaration();
-    builder.doctype('note SYSTEM "Note.dtd"');
+    builder.doctype('note', systemId: 'Note.dtd');
     builder.processing('processing', 'instruction');
     builder.element('element1', attributes: {'attribute1': 'value1'}, nest: () {
       builder.attribute('attribute2', 'value2',
@@ -214,6 +215,51 @@ void main() {
     const expected = '<text>abcdef</text>';
     expect(actual, expected);
   });
+  test('doctype (plain)', () {
+    final builder = XmlBuilder()
+      ..doctype('note')
+      ..element('root');
+    final xml = builder.buildDocument();
+    assertDocumentTreeInvariants(xml);
+    final actual = xml.toString();
+    const expected = '<!DOCTYPE note><root/>';
+    expect(actual, expected);
+  });
+  test('doctype (system ID)', () {
+    final builder = XmlBuilder()
+      ..doctype('note', systemId: 'system.dtd')
+      ..element('root');
+    final xml = builder.buildDocument();
+    assertDocumentTreeInvariants(xml);
+    final actual = xml.toString();
+    const expected = '<!DOCTYPE note SYSTEM "system.dtd"><root/>';
+    expect(actual, expected);
+  });
+  test('doctype (public ID)', () {
+    final builder = XmlBuilder()
+      ..doctype('note', publicId: 'public.dtd', systemId: 'system.dtd')
+      ..element('root');
+    final xml = builder.buildDocument();
+    assertDocumentTreeInvariants(xml);
+    final actual = xml.toString();
+    const expected = '<!DOCTYPE note PUBLIC "public.dtd" "system.dtd"><root/>';
+    expect(actual, expected);
+  });
+  test('doctype (internal subset)', () {
+    final builder = XmlBuilder()
+      ..doctype('note', internalSubset: '<!ELEMENT br EMPTY>')
+      ..element('root');
+    final xml = builder.buildDocument();
+    assertDocumentTreeInvariants(xml);
+    final actual = xml.toString();
+    const expected = '<!DOCTYPE note [<!ELEMENT br EMPTY>]><root/>';
+    expect(actual, expected);
+  });
+  test('doctype (error)', () {
+    final builder = XmlBuilder();
+    expect(() => builder.doctype('note', publicId: 'public.dtd'),
+        throwsArgumentError);
+  });
   test('xml', () {
     final builder = XmlBuilder();
     builder.xml('<element attr="value"/>');
@@ -249,7 +295,15 @@ void main() {
   test('xml (invalid)', () {
     final builder = XmlBuilder();
     builder.element('outer', nest: () {
-      expect(() => builder.xml('<broken>'), throwsA(isXmlParserException));
+      expect(
+          () => builder.xml('<broken>'),
+          throwsA(isXmlTagException(
+            message: 'Missing </broken>',
+            expectedName: 'broken',
+            actualName: isNull,
+            buffer: '<broken>',
+            position: 8,
+          )));
     });
     final xml = builder.buildDocument();
     assertDocumentTreeInvariants(xml);
@@ -428,8 +482,23 @@ void main() {
   });
   test('declaration outside of document', () {
     final builder = XmlBuilder();
-    expect(() => builder.element('data', nest: builder.declaration),
-        throwsA(isXmlNodeTypeException));
+    expect(
+        () => builder.element('data', nest: builder.declaration),
+        throwsA(isXmlNodeTypeException(
+            message: startsWith('Got XmlNodeType.DECLARATION'),
+            node: isNotNull,
+            types: contains(XmlNodeType.ELEMENT))));
+  });
+  test('exception during nesting', () {
+    final builder = XmlBuilder();
+    builder.element('outer', nest: () {
+      expect(
+        () => builder.element('inner', nest: () => throw UnimplementedError()),
+        throwsUnsupportedError,
+      );
+    });
+    final document = builder.buildDocument();
+    expect(document.toString(), '<outer/>');
   });
   test('incomplete builder', () {
     final builder = XmlBuilder();
@@ -455,11 +524,4 @@ void main() {
     final xml = builder.buildFragment();
     assertFragmentInvariants(xml);
   });
-  test('deprecated builder', () {
-    final builder = XmlBuilder();
-    builder.element('element-one');
-    // ignore: deprecated_member_use_from_same_package
-    final xml = builder.build();
-    assertDocumentInvariants(xml);
-  });
 }
