@@ -11,7 +11,7 @@ import 'package:flutter/widgets.dart';
 void main() => runApp(const ExampleApp());
 
 class ExampleApp extends StatelessWidget {
-  const ExampleApp({Key? key}) : super(key: key);
+  const ExampleApp({super.key});
 
   @override
   Widget build(BuildContext context) {
@@ -23,7 +23,7 @@ class ExampleApp extends StatelessWidget {
 }
 
 class ExampleWidget extends StatelessWidget {
-  const ExampleWidget({Key? key}) : super(key: key);
+  const ExampleWidget({super.key});
 
   @override
   Widget build(BuildContext context) {
@@ -34,7 +34,7 @@ class ExampleWidget extends StatelessWidget {
         fontFamily: 'Sorts Mill Goudy',
         fontFeatures: <FontFeature>[
           FontFeature.historicalForms(), // Enables "hist".
-          FontFeature.historicalLigatures() // Enables "hlig".
+          FontFeature.historicalLigatures(), // Enables "hlig".
         ],
       ),
     );
