@@ -405,8 +405,9 @@ class StrutStyle with Diagnosticable {
   /// The package name should be provided by the `package` argument in the
   /// constructor.
   List<String>? get fontFamilyFallback {
-    if (_package != null && _fontFamilyFallback != null)
+    if (_package != null && _fontFamilyFallback != null) {
       return _fontFamilyFallback!.map((String family) => 'packages/$_package/$family').toList();
+    }
     return _fontFamilyFallback;
   }
   final List<String>? _fontFamilyFallback;
@@ -518,8 +519,9 @@ class StrutStyle with Diagnosticable {
   ///
   ///  * [TextSpan.compareTo], which does the same thing for entire [TextSpan]s.
   RenderComparison compareTo(StrutStyle other) {
-    if (identical(this, other))
+    if (identical(this, other)) {
       return RenderComparison.identical;
+    }
     if (fontFamily != other.fontFamily ||
         fontSize != other.fontSize ||
         fontWeight != other.fontWeight ||
@@ -527,8 +529,9 @@ class StrutStyle with Diagnosticable {
         height != other.height ||
         leading != other.leading ||
         forceStrutHeight != other.forceStrutHeight ||
-        !listEquals(fontFamilyFallback, other.fontFamilyFallback))
+        !listEquals(fontFamilyFallback, other.fontFamilyFallback)) {
       return RenderComparison.layout;
+    }
     return RenderComparison.identical;
   }
 
@@ -541,8 +544,9 @@ class StrutStyle with Diagnosticable {
   ///
   /// If the given text style is null, returns this strut style.
   StrutStyle inheritFromTextStyle(TextStyle? other) {
-    if (other == null)
+    if (other == null) {
       return this;
+    }
 
     return StrutStyle(
       fontFamily: fontFamily ?? other.fontFamily,
@@ -560,10 +564,12 @@ class StrutStyle with Diagnosticable {
 
   @override
   bool operator ==(Object other) {
-    if (identical(this, other))
+    if (identical(this, other)) {
       return true;
-    if (other.runtimeType != runtimeType)
+    }
+    if (other.runtimeType != runtimeType) {
       return false;
+    }
     return other is StrutStyle
         && other.fontFamily == fontFamily
         && other.fontSize == fontSize
@@ -592,8 +598,9 @@ class StrutStyle with Diagnosticable {
   @override
   void debugFillProperties(DiagnosticPropertiesBuilder properties, { String prefix = '' }) {
     super.debugFillProperties(properties);
-    if (debugLabel != null)
+    if (debugLabel != null) {
       properties.add(MessageProperty('${prefix}debugLabel', debugLabel!));
+    }
     final List<DiagnosticsNode> styles = <DiagnosticsNode>[
       StringProperty('${prefix}family', fontFamily, defaultValue: null, quoted: false),
       IterableProperty<String>('${prefix}familyFallback', fontFamilyFallback, defaultValue: null),
@@ -619,7 +626,8 @@ class StrutStyle with Diagnosticable {
     final bool styleSpecified = styles.any((DiagnosticsNode n) => !n.isFiltered(DiagnosticLevel.info));
     styles.forEach(properties.add);
 
-    if (!styleSpecified)
+    if (!styleSpecified) {
       properties.add(FlagProperty('forceStrutHeight', value: forceStrutHeight, ifTrue: '$prefix<strut height forced>', ifFalse: '$prefix<strut height normal>'));
+    }
   }
 }
