@@ -6,7 +6,7 @@ import 'package:flutter/material.dart';
 import 'package:flutter_test/flutter_test.dart';
 
 class TestIcon extends StatefulWidget {
-  const TestIcon({Key? key}) : super(key: key);
+  const TestIcon({super.key});
 
   @override
   TestIconState createState() => TestIconState();
@@ -23,7 +23,7 @@ class TestIconState extends State<TestIcon> {
 }
 
 class TestText extends StatefulWidget {
-  const TestText(this.text, {Key? key}) : super(key: key);
+  const TestText(this.text, {super.key});
 
   final String text;
 
