@@ -3,7 +3,6 @@
 // found in the LICENSE file.
 
 import 'dart:async';
-import 'dart:typed_data';
 
 import 'package:flutter/foundation.dart';
 import 'package:flutter/services.dart';
@@ -46,11 +45,16 @@ class FakePlatformViewController extends PlatformViewController {
 }
 
 class FakeAndroidViewController implements AndroidViewController {
-  FakeAndroidViewController(this.viewId);
+  FakeAndroidViewController(this.viewId, {this.requiresSize = false});
 
   bool disposed = false;
   bool focusCleared = false;
   bool created = false;
+  // If true, [create] won't be considered to have been called successfully
+  // unless it includes a size.
+  bool requiresSize;
+
+  bool _createCalledSuccessfully = false;
 
   /// Events that are dispatched.
   List<PointerEvent> dispatchedPointerEvents = <PointerEvent>[];
@@ -93,6 +97,9 @@ class FakeAndroidViewController implements AndroidViewController {
   @override
   int get textureId => 0;
 
+  @override
+  bool get awaitingCreation => !_createCalledSuccessfully;
+
   @override
   bool get isCreated => created;
 
@@ -102,9 +109,7 @@ class FakeAndroidViewController implements AndroidViewController {
   }
 
   @override
-  void removeOnPlatformViewCreatedListener(PlatformViewCreatedCallback listener) {
-    throw UnimplementedError();
-  }
+  void removeOnPlatformViewCreatedListener(PlatformViewCreatedCallback listener) {}
 
   @override
   Future<void> sendMotionEvent(AndroidMotionEvent event) {
@@ -117,7 +122,13 @@ class FakeAndroidViewController implements AndroidViewController {
   }
 
   @override
-  Future<void> create() async {}
+  Future<void> create({Size? size}) async {
+    assert(!_createCalledSuccessfully);
+    if (requiresSize && size != null) {
+      assert(!size.isEmpty);
+    }
+    _createCalledSuccessfully = size != null || !requiresSize;
+  }
 
   @override
   List<PlatformViewCreatedCallback> get createdCallbacks => <PlatformViewCreatedCallback>[];
@@ -186,17 +197,19 @@ class FakeAndroidPlatformViewsController {
     final bool? hybrid = args['hybrid'] as bool?;
     final Uint8List? creationParams = args['params'] as Uint8List?;
 
-    if (_views.containsKey(id))
+    if (_views.containsKey(id)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to create an already created platform view, view id: $id',
       );
+    }
 
-    if (!_registeredViewTypes.contains(viewType))
+    if (!_registeredViewTypes.contains(viewType)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to create a platform view of unregistered type: $viewType',
       );
+    }
 
     if (createCompleter != null) {
       await createCompleter!.future;
@@ -225,11 +238,12 @@ class FakeAndroidPlatformViewsController {
       throw ArgumentError('An $AndroidViewController not using hybrid composition must pass `hybrid: false`');
     }
 
-    if (!_views.containsKey(id))
+    if (!_views.containsKey(id)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to dispose a platform view with unknown id: $id',
       );
+    }
 
     _views.remove(id);
     return Future<dynamic>.sync(() => null);
@@ -241,11 +255,12 @@ class FakeAndroidPlatformViewsController {
     final double width = args['width'] as double;
     final double height = args['height'] as double;
 
-    if (!_views.containsKey(id))
+    if (!_views.containsKey(id)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to resize a platform view with unknown id: $id',
       );
+    }
 
     if (resizeCompleter != null) {
       await resizeCompleter!.future;
@@ -279,8 +294,9 @@ class FakeAndroidPlatformViewsController {
       pointerOffsets.add(Offset(x, y));
     }
 
-    if (!motionEvents.containsKey(id))
+    if (!motionEvents.containsKey(id)) {
       motionEvents[id] = <FakeAndroidMotionEvent> [];
+    }
 
     motionEvents[id]!.add(FakeAndroidMotionEvent(action, pointerIds, pointerOffsets));
     return Future<dynamic>.sync(() => null);
@@ -291,11 +307,12 @@ class FakeAndroidPlatformViewsController {
     final int id = args['id'] as int;
     final int layoutDirection = args['direction'] as int;
 
-    if (!_views.containsKey(id))
+    if (!_views.containsKey(id)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to resize a platform view with unknown id: $id',
       );
+    }
 
     _views[id] = _views[id]!.copyWith(layoutDirection: layoutDirection);
 
@@ -305,11 +322,12 @@ class FakeAndroidPlatformViewsController {
   Future<dynamic> _clearFocus(MethodCall call) {
     final int id = call.arguments as int;
 
-    if (!_views.containsKey(id))
+    if (!_views.containsKey(id)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to clear the focus on a platform view with unknown id: $id',
       );
+    }
 
     lastClearedFocusViewId = id;
     return Future<dynamic>.sync(() => null);
@@ -340,6 +358,13 @@ class FakeIosPlatformViewsController {
     _registeredViewTypes.add(viewType);
   }
 
+  void invokeViewFocused(int viewId) {
+    final MethodCodec codec = SystemChannels.platform_views.codec;
+    final ByteData data = codec.encodeMethodCall(MethodCall('viewFocused', viewId));
+    ServicesBinding.instance.defaultBinaryMessenger
+        .handlePlatformMessage(SystemChannels.platform_views.name, data, (ByteData? data) {});
+  }
+
   Future<dynamic> _onMethodCall(MethodCall call) {
     switch(call.method) {
       case 'create':
@@ -355,8 +380,9 @@ class FakeIosPlatformViewsController {
   }
 
   Future<dynamic> _create(MethodCall call) async {
-    if (creationDelay != null)
+    if (creationDelay != null) {
       await creationDelay!.future;
+    }
     final Map<dynamic, dynamic> args = call.arguments as Map<dynamic, dynamic>;
     final int id = args['id'] as int;
     final String viewType = args['viewType'] as String;
@@ -444,17 +470,19 @@ class FakeHtmlPlatformViewsController {
     final int id = args['id'] as int;
     final String viewType = args['viewType'] as String;
 
-    if (_views.containsKey(id))
+    if (_views.containsKey(id)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to create an already created platform view, view id: $id',
       );
+    }
 
-    if (!_registeredViewTypes.contains(viewType))
+    if (!_registeredViewTypes.contains(viewType)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to create a platform view of unregistered type: $viewType',
       );
+    }
 
     if (createCompleter != null) {
       await createCompleter!.future;
@@ -467,11 +495,12 @@ class FakeHtmlPlatformViewsController {
   Future<dynamic> _dispose(MethodCall call) {
     final int id = call.arguments as int;
 
-    if (!_views.containsKey(id))
+    if (!_views.containsKey(id)) {
       throw PlatformException(
         code: 'error',
         message: 'Trying to dispose a platform view with unknown id: $id',
       );
+    }
 
     _views.remove(id);
     return Future<dynamic>.sync(() => null);
@@ -500,8 +529,9 @@ class FakeAndroidPlatformView {
 
   @override
   bool operator ==(Object other) {
-    if (other.runtimeType != runtimeType)
+    if (other.runtimeType != runtimeType) {
       return false;
+    }
     return other is FakeAndroidPlatformView
         && other.id == id
         && other.type == type
@@ -563,8 +593,9 @@ class FakeUiKitView {
 
   @override
   bool operator ==(Object other) {
-    if (other.runtimeType != runtimeType)
+    if (other.runtimeType != runtimeType) {
       return false;
+    }
     return other is FakeUiKitView
         && other.id == id
         && other.type == type
@@ -589,8 +620,9 @@ class FakeHtmlPlatformView {
 
   @override
   bool operator ==(Object other) {
-    if (other.runtimeType != runtimeType)
+    if (other.runtimeType != runtimeType) {
       return false;
+    }
     return other is FakeHtmlPlatformView
         && other.id == id
         && other.type == type;
