@@ -9,83 +9,7 @@ import 'package:flutter/rendering.dart';
 import 'package:flutter/services.dart';
 import 'package:flutter_test/flutter_test.dart';
 
-typedef PostInvokeCallback = void Function({Action<Intent> action, Intent intent, ActionDispatcher dispatcher});
-
-class TestIntent extends Intent {
-  const TestIntent();
-}
-
-class SecondTestIntent extends TestIntent {
-  const SecondTestIntent();
-}
-
-class ThirdTestIntent extends SecondTestIntent {
-  const ThirdTestIntent();
-}
-
-class TestAction extends CallbackAction<TestIntent> {
-  TestAction({
-    required OnInvokeCallback onInvoke,
-  })  : assert(onInvoke != null),
-        super(onInvoke: onInvoke);
-
-  @override
-  bool isEnabled(TestIntent intent) => enabled;
-
-  bool get enabled => _enabled;
-  bool _enabled = true;
-  set enabled(bool value) {
-    if (_enabled == value) {
-      return;
-    }
-    _enabled = value;
-    notifyActionListeners();
-  }
-
-  @override
-  void addActionListener(ActionListenerCallback listener) {
-    super.addActionListener(listener);
-    listeners.add(listener);
-  }
-
-  @override
-  void removeActionListener(ActionListenerCallback listener) {
-    super.removeActionListener(listener);
-    listeners.remove(listener);
-  }
-  List<ActionListenerCallback> listeners = <ActionListenerCallback>[];
-
-  void _testInvoke(TestIntent intent) => invoke(intent);
-}
-
-class TestDispatcher extends ActionDispatcher {
-  const TestDispatcher({this.postInvoke});
-
-  final PostInvokeCallback? postInvoke;
-
-  @override
-  Object? invokeAction(Action<Intent> action, Intent intent, [BuildContext? context]) {
-    final Object? result = super.invokeAction(action, intent, context);
-    postInvoke?.call(action: action, intent: intent, dispatcher: this);
-    return result;
-  }
-}
-
-class TestDispatcher1 extends TestDispatcher {
-  const TestDispatcher1({PostInvokeCallback? postInvoke}) : super(postInvoke: postInvoke);
-}
-
 void main() {
-  testWidgets('CallbackAction passes correct intent when invoked.', (WidgetTester tester) async {
-    late Intent passedIntent;
-    final TestAction action = TestAction(onInvoke: (Intent intent) {
-      passedIntent = intent;
-      return true;
-    });
-    const TestIntent intent = TestIntent();
-    action._testInvoke(intent);
-    expect(passedIntent, equals(intent));
-  });
   group(ActionDispatcher, () {
     testWidgets('ActionDispatcher invokes actions when asked.', (WidgetTester tester) async {
       await tester.pumpWidget(Container());
@@ -196,7 +120,7 @@ void main() {
       await tester.pump();
       final Object? result = Actions.maybeInvoke(
         containerKey.currentContext!,
-        DoNothingIntent(),
+        const DoNothingIntent(),
       );
       expect(result, isNull);
       expect(invoked, isFalse);
@@ -222,7 +146,7 @@ void main() {
       await tester.pump();
       final Object? result = Actions.maybeInvoke(
         containerKey.currentContext!,
-        DoNothingIntent(),
+        const DoNothingIntent(),
       );
       expect(result, isNull);
       expect(invoked, isFalse);
@@ -434,7 +358,6 @@ void main() {
       focusNode.requestFocus();
       await tester.pump();
       final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse);
-      addTearDown(gesture.removePointer);
       await gesture.moveTo(tester.getCenter(find.byKey(containerKey)));
       await tester.pump();
       await tester.sendKeyEvent(LogicalKeyboardKey.enter);
@@ -474,7 +397,6 @@ void main() {
       );
       final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse, pointer: 1);
       await gesture.addPointer(location: const Offset(1, 1));
-      addTearDown(gesture.removePointer);
       await tester.pump();
 
       expect(RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1), SystemMouseCursors.text);
@@ -828,7 +750,6 @@ void main() {
       focusNode.requestFocus();
       await tester.pump();
       final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse);
-      addTearDown(gesture.removePointer);
       await gesture.moveTo(tester.getCenter(find.byKey(containerKey)));
       await tester.pump();
       await tester.sendKeyEvent(LogicalKeyboardKey.enter);
@@ -892,7 +813,6 @@ void main() {
       focusNode.requestFocus();
       await tester.pump();
       final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse);
-      addTearDown(gesture.removePointer);
       await gesture.moveTo(tester.getCenter(find.byKey(containerKey)));
       await tester.pump();
       await tester.sendKeyEvent(LogicalKeyboardKey.enter);
@@ -1033,6 +953,29 @@ void main() {
     );
   });
 
+  group('Action subclasses', () {
+    testWidgets('CallbackAction passes correct intent when invoked.', (WidgetTester tester) async {
+      late Intent passedIntent;
+      final TestAction action = TestAction(onInvoke: (Intent intent) {
+        passedIntent = intent;
+        return true;
+      });
+      const TestIntent intent = TestIntent();
+      action._testInvoke(intent);
+      expect(passedIntent, equals(intent));
+    });
+    testWidgets('VoidCallbackAction', (WidgetTester tester) async {
+      bool called = false;
+      void testCallback() {
+        called = true;
+      }
+      final VoidCallbackAction action = VoidCallbackAction();
+      final VoidCallbackIntent intent = VoidCallbackIntent(testCallback);
+      action.invoke(intent);
+      expect(called, isTrue);
+    });
+  });
+
   group('Diagnostics', () {
     testWidgets('default Intent debugFillProperties', (WidgetTester tester) async {
       final DiagnosticPropertiesBuilder builder = DiagnosticPropertiesBuilder();
@@ -1470,7 +1413,7 @@ void main() {
                   setState = stateSetter;
                   return Actions(
                     actions: <Type, Action<Intent>> {
-                      if (action2LookupContext != null) LogIntent: Action<LogIntent>.overridable(defaultAction: LogInvocationAction(actionName: 'action2'), context: action2LookupContext!)
+                      if (action2LookupContext != null) LogIntent: Action<LogIntent>.overridable(defaultAction: LogInvocationAction(actionName: 'action2'), context: action2LookupContext!),
                     },
                     child: Builder(
                       builder: (BuildContext context3) {
@@ -1579,7 +1522,7 @@ void main() {
                                 context: context2,
                               ),
                               context: context3,
-                            )
+                            ),
                           },
                           child: Builder(
                             builder: (BuildContext context4) {
@@ -1766,6 +1709,72 @@ void main() {
   });
 }
 
+typedef PostInvokeCallback = void Function({Action<Intent> action, Intent intent, ActionDispatcher dispatcher});
+
+class TestIntent extends Intent {
+  const TestIntent();
+}
+
+class SecondTestIntent extends TestIntent {
+  const SecondTestIntent();
+}
+
+class ThirdTestIntent extends SecondTestIntent {
+  const ThirdTestIntent();
+}
+
+class TestAction extends CallbackAction<TestIntent> {
+  TestAction({
+    required OnInvokeCallback onInvoke,
+  })  : assert(onInvoke != null),
+        super(onInvoke: onInvoke);
+
+  @override
+  bool isEnabled(TestIntent intent) => enabled;
+
+  bool get enabled => _enabled;
+  bool _enabled = true;
+  set enabled(bool value) {
+    if (_enabled == value) {
+      return;
+    }
+    _enabled = value;
+    notifyActionListeners();
+  }
+
+  @override
+  void addActionListener(ActionListenerCallback listener) {
+    super.addActionListener(listener);
+    listeners.add(listener);
+  }
+
+  @override
+  void removeActionListener(ActionListenerCallback listener) {
+    super.removeActionListener(listener);
+    listeners.remove(listener);
+  }
+  List<ActionListenerCallback> listeners = <ActionListenerCallback>[];
+
+  void _testInvoke(TestIntent intent) => invoke(intent);
+}
+
+class TestDispatcher extends ActionDispatcher {
+  const TestDispatcher({this.postInvoke});
+
+  final PostInvokeCallback? postInvoke;
+
+  @override
+  Object? invokeAction(Action<Intent> action, Intent intent, [BuildContext? context]) {
+    final Object? result = super.invokeAction(action, intent, context);
+    postInvoke?.call(action: action, intent: intent, dispatcher: this);
+    return result;
+  }
+}
+
+class TestDispatcher1 extends TestDispatcher {
+  const TestDispatcher1({super.postInvoke});
+}
+
 class TestContextAction extends ContextAction<TestIntent> {
   List<BuildContext?> capturedContexts = <BuildContext?>[];
 
@@ -1843,7 +1852,7 @@ class LogInvocationContextAction extends ContextAction<LogIntent> {
 }
 
 class LogInvocationButDeferIsEnabledAction extends LogInvocationAction {
-  LogInvocationButDeferIsEnabledAction({ required String actionName }) : super(actionName: actionName);
+  LogInvocationButDeferIsEnabledAction({ required super.actionName });
 
   // Defer `isActionEnabled` to the overridable action.
   @override
@@ -1852,10 +1861,10 @@ class LogInvocationButDeferIsEnabledAction extends LogInvocationAction {
 
 class RedirectOutputAction extends LogInvocationAction {
   RedirectOutputAction({
-      required String actionName,
-      bool enabled = true,
+      required super.actionName,
+      super.enabled,
       required this.newLog,
-  }) : super(actionName: actionName, enabled: enabled);
+  });
 
   final List<String> newLog;
 
