@@ -102,8 +102,9 @@ void main() {
     await tester.drag(find.text('Arkansas'), const Offset(0.0, -200.0));
     await tester.pump();
 
-    for (int i = 0; i < 4; ++i)
+    for (int i = 0; i < 4; ++i) {
       expect(find.text(kStates[i]), findsNothing);
+    }
 
     for (int i = 4; i < 12; ++i) {
       await tester.tap(find.text(kStates[i]));
@@ -644,13 +645,50 @@ void main() {
     expect(counters[4], 2);
   });
 
+  testWidgets('GridView does not report visual overflow unnecessarily', (WidgetTester tester) async {
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: GridView(
+          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
+          children: <Widget>[
+            Container(height: 200.0),
+          ],
+        ),
+      ),
+    );
+
+    // 1st, check that the render object has received the default clip behavior.
+    final RenderViewport renderObject = tester.allRenderObjects.whereType<RenderViewport>().first;
+    expect(renderObject.clipBehavior, equals(Clip.hardEdge));
+
+    // The context will get Clip.none because there is no actual visual overflow.
+    final TestClipPaintingContext context = TestClipPaintingContext();
+    renderObject.paint(context, Offset.zero);
+    expect(context.clipBehavior, equals(Clip.none));
+  });
+
   testWidgets('GridView respects clipBehavior', (WidgetTester tester) async {
     await tester.pumpWidget(
       Directionality(
         textDirection: TextDirection.ltr,
         child: GridView(
           gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
-          children: <Widget>[Container(height: 2000.0)],
+          children: <Widget>[
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+          ],
         ),
       ),
     );
@@ -671,7 +709,21 @@ void main() {
         child: GridView(
           gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
           clipBehavior: Clip.antiAlias,
-          children: <Widget>[Container(height: 2000.0)],
+          children: <Widget>[
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+            Container(height: 2000.0),
+          ],
         ),
       ),
     );
