@@ -3,7 +3,6 @@
 // found in the LICENSE file.
 
 @TestOn('!chrome')
-import 'dart:typed_data';
 import 'dart:ui' as ui show Image;
 
 import 'package:flutter/foundation.dart';
@@ -62,8 +61,9 @@ class TestAssetBundle extends CachingAssetBundle {
 
   @override
   Future<String> loadString(String key, { bool cache = true }) {
-    if (key == 'AssetManifest.json')
+    if (key == 'AssetManifest.json') {
       return SynchronousFuture<String>(manifest);
+    }
     return SynchronousFuture<String>('');
   }
 
@@ -78,12 +78,12 @@ class FakeImageStreamCompleter extends ImageStreamCompleter {
 }
 
 class TestAssetImage extends AssetImage {
-  const TestAssetImage(String name, this.images) : super(name);
+  const TestAssetImage(super.name, this.images);
 
   final Map<double, ui.Image> images;
 
   @override
-  ImageStreamCompleter load(AssetBundleImageKey key, DecoderCallback decode) {
+  ImageStreamCompleter loadBuffer(AssetBundleImageKey key, DecoderBufferCallback decode) {
     late ImageInfo imageInfo;
     key.bundle.load(key.name).then<void>((ByteData data) {
       final ui.Image image = images[scaleOf(data)]!;
