@@ -1048,13 +1048,16 @@ void main() {
         );
 
       expect(find.byType(RichText), paints..something((Symbol method, List<dynamic> arguments) {
-        if (method != #drawParagraph)
+        if (method != #drawParagraph) {
           return false;
+        }
         final ui.Paragraph paragraph = arguments[0] as ui.Paragraph;
-        if (paragraph.longestLine > paragraph.width)
+        if (paragraph.longestLine > paragraph.width) {
           throw 'paragraph width (${paragraph.width}) greater than its longest line (${paragraph.longestLine}).';
-        if (paragraph.width >= 400)
+        }
+        if (paragraph.width >= 400) {
           throw 'paragraph.width (${paragraph.width}) >= 400';
+        }
         return true;
       }));
     },
